@@ -1,8 +1,6 @@
-"""Top-level package for moralis-streams-client."""
+"""Client module for the Moralis Streams API, including a CLI and a webhook utility for buffering and forwarding endpoint callbacks."""
 
 from .api import MoralisStreamsApi
-from .auth import Signature
-from .cli import cli
 from .defaults import ACTIVE, ERROR, PAUSED, REGION_CHOICES, STATUS_CHOICES
 from .exceptions import (
     MoralisStreamsCallFailed,
@@ -17,7 +15,6 @@ __all__ = [
     __timestamp__,
     __author__,
     __email__,
-    "cli",
     "ACTIVE",
     "PAUSED",
     "ERROR",
@@ -28,5 +25,4 @@ __all__ = [
     "MoralisStreamsErrorReturned",
     "MoralisStreamsResponseFormatError",
     "MoralisStreamsApi",
-    "Signature",
 ]
